module.exports = defineTest({
	description: 'deoptimizes cached properties and return values if necessary (#3264)'
});
